@@ -64,7 +64,8 @@ class SynologyFileCache():
                 and not isinstance(file_path, dict) and not isinstance(file_path, list) and file_path is not None:
             raise FileNotFoundError(file_path)
 
-        local_path = '/tmp/%s.%s/%s' % (self.random_str(30), self.random_str(30), key)
+        local_cache_path = '/tmp/%s.%s/%s' % (self.random_str(30), self.random_str(30), key)
+        local_path = local_cache_path
         cache_path = "%s/%s" % (self.cache_path_root, self.namespace)
 
         if not self._exist(file_path=cache_path):
@@ -98,7 +99,13 @@ class SynologyFileCache():
             if del_local:
                 if os.path.exists(local_path):
                     os.remove(local_path)
+
+        if os.path.exists(local_cache_path):
+            os.remove(local_cache_path)
+
         logging.info(res)
+        return True
+
     def get(self, key, local_file):
         """
         从群晖获取缓存文件
